==> babel-build-1.0.1.tgz: package/lib/build.js <==
'use strict';

var _run = require('./run');

var _run2 = _interopRequireDefault(_run);

var _copy = require('./copy');

var _copy2 = _interopRequireDefault(_copy);

var _clean = require('./clean');

var _clean2 = _interopRequireDefault(_clean);

var _bundle = require('./bundle');

var _bundle2 = _interopRequireDefault(_bundle);

var _utils = require('./utils');

var _webpack = require('./webpack.config');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; } /**
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * Created by Zhengfeng.Yao on 16/9/22.
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            */


module.exports = function () {
  var _ref = _asyncToGenerator(regeneratorRuntime.mark(function _callee(options) {
    var webpackConfig, dirs, config;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            if (!options.clean) {
              _context.next = 5;
              break;
            }

            webpackConfig = (0, _webpack.getWebpackConfig)(options);
            dirs = webpackConfig.map(function (config) {
              return config.output.path;
            });
            _context.next = 5;
            return (0, _run2.default)(_clean2.default.bind(undefined, dirs));

          case 5:
            config = (0, _utils.loadAegisConfig)(options.dev ? '.dev' : '');

            if (!config.copy) {
              _context.next = 9;
              break;
            }

            _context.next = 9;
            return (0, _run2.default)(_copy2.default.bind(undefined, config.copy));

          case 9:
            _context.next = 11;
            return (0, _run2.default)(_bundle2.default.bind(undefined, options));

          case 11:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, this);
  }));

  function build(_x) {
    return _ref.apply(this, arguments);
  }

  return build;
}();

==> babel-build-1.0.2.tgz: package/lib/build.js <==
'use strict';

var _run = require('./run');

var _run2 = _interopRequireDefault(_run);

var _copy = require('./copy');

var _copy2 = _interopRequireDefault(_copy);

var _clean = require('./clean');

var _clean2 = _interopRequireDefault(_clean);

var _bundle = require('./bundle');

var _bundle2 = _interopRequireDefault(_bundle);

var _utils = require('./utils');

var _webpack = require('./webpack.config');

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _asyncToGenerator(fn) { return function () { var gen = fn.apply(this, arguments); return new Promise(function (resolve, reject) { function step(key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { return Promise.resolve(value).then(function (value) { step("next", value); }, function (err) { step("throw", err); }); } } return step("next"); }); }; } /**
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            * Created by Zhengfeng.Yao on 16/9/22.
                                                                                                                                                                                                                                                                                                                                                                                                                                                                            */


module.exports = function () {
  var _ref = _asyncToGenerator(regeneratorRuntime.mark(function _callee(options) {
    var webpackConfig, dirs, config;
    return regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            if (!options.clean) {
              _context.next = 5;
              break;
            }

            webpackConfig = (0, _webpack.getWebpackConfig)(options);
            dirs = webpackConfig.map(function (config) {
              return config.output.path;
            });
            _context.next = 5;
            return (0, _run2.default)(_clean2.default.bind(undefined, dirs, options.force));

          case 5:
            config = (0, _utils.loadAegisConfig)(options.dev ? '.dev' : '');

            if (!config.copy) {
              _context.next = 9;
              break;
            }

            _context.next = 9;
            return (0, _run2.default)(_copy2.default.bind(undefined, config.copy));

          case 9:
            _context.next = 11;
            return (0, _run2.default)(_bundle2.default.bind(undefined, options));

          case 11:
          case 'end':
            return _context.stop();
        }
      }
    }, _callee, this);
  }));

  function build(_x) {
    return _ref.apply(this, arguments);
  }

  return build;
}();
